package com.overseas.website.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.overseas.website.utils.RequestUtil;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.HashMap;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/10/18
 */
@Controller
public class PageController {
    /**
     * 页面路径
     */
    @GetMapping("/{path}.html")
    public String page(final Model model, @PathVariable("path") String path) {
        model.addAttribute("path", path);
        if ("index".equals(path)){
            try {
                String floorResult = RequestUtil.sendGet("https://core.caimei365.com/commodity/classify/product?pageId=287&source=1");
                Map<String, Object> floorMap = JSONObject.parseObject(floorResult, Map.class);
                Map<String, Object> floorJson = JSONObject.parseObject(String.valueOf(floorMap.get("data")), Map.class);
                model.addAttribute("floorJson", floorJson);
            } catch (Exception e) {
                System.out.println(e);
                model.addAttribute("floorJson", new HashMap<>());
            }
        }
        return path;
    }

    /**
     * 商品详情页面
     */
    @GetMapping("/product/{id}.html")
    public String product(final Model model, @PathVariable("id") String productId) {
        model.addAttribute("path", "product");
        Map<String, Object> product = new HashMap<>();
        try {
            String floorResult = RequestUtil.sendGet("https://core.caimei365.com/commodity/product/details?productId="+productId);
            Map<String, Object> floorMap = JSONObject.parseObject(floorResult, Map.class);
            product = JSONObject.parseObject(String.valueOf(floorMap.get("data")), Map.class);
        } catch (Exception e) {
            System.out.println(e);
        }
        model.addAttribute("product", product);
        return "product";
    }

    /**
     * 商品列表页面
     */
    @GetMapping("/list/{id}.html")
    public String page(final Model model, @PathVariable("id") String pageId, @RequestParam("title") String pageTitle) {
        model.addAttribute("path", "list");
        model.addAttribute("pageId", pageId);
        model.addAttribute("pageTitle", pageTitle);
            try {
                String productResult = RequestUtil.sendGet("https://core.caimei365.com/commodity/search/query/product/type?idType=1&id="+pageId);
                Map<String, Object> productMap = JSONObject.parseObject(productResult, Map.class);
                String data = (String) productMap.get("data");
                JSONObject productObj = JSONObject.parseObject(data);
                JSONArray productList = (JSONArray) productObj.get("items");
                model.addAttribute("productList", productList);
            } catch (Exception e) {
                System.out.println(e);
                model.addAttribute("productList", new JSONArray());
            }
        return "list";
    }
}
